import random
import os


#path = os.path.abspath("new.py")
#print(path)
def name_array(file):
    with open(file) as fp:
        new_list = []
        for line in fp:
            new_list.append(line.strip())
    return new_list


file = os.path.abspath("male_first_names.py")
print(file)
male_names_file = name_array(file)

file = os.path.abspath("female_first_names.py")
female_names_file = name_array(file)

file = os.path.abspath("last_names.py")
last_names_file = name_array(file)

file = os.path.abspath("home_address.py")
home_address_file = name_array(file)

file = os.path.abspath("city.py")
city_name_file = name_array(file)


def quin():
    result = f"['Avihinsaka uwathy','Nihada Mawatha ','Palu Niwahana']"
    return result



def femalename():
    result = f"[{random.choice(female_names_file)} {random.choice(last_names_file)}]"
    return result



def femaleaddress():
    result = f"[{random.choice(female_names_file)} {random.choice(last_names_file)},{random.choice(home_address_file)},{random.choice(city_name_file)}]"
    return result



def maleaddress():
    result = f"['{random.choice(male_names_file)} {random.choice(last_names_file)}','{random.choice(home_address_file)}','{random.choice(city_name_file)}']"
    return result






Colombo
Kandy
Gampaha
Ella
Bandarawela
Badulla
Jafna
Galle
Matara 
Hatton
Panadura
Maradana
Kaluthara
Hambanthota
Haputhale
Diyatalawa
Monaragala
Rathnapura
Kurunagela
Colombo2
Colombo3
Colombo4
Colombo5
Colombo6
Colombo7
Colombo8
Colombo8
Colombo10
Colombo11
Colombo12
Colombo13
Colombo14
Colombo15


import random
from .Data import *


# prastha_pirulu
def prasthapirulu():
    return random.choice(Prastha_Pirulu_List)


# prastha_pirulu
def pp():
    return random.choice(Prastha_Pirulu_List)


# theravili
def theravili():
    return random.choice(theravili_List)


# thun_theravili
def thun_theravili():
    return random.choice(thun_theravili_List)


# thun_theravili shorts
def thun():
    return random.choice(thun_theravili_List)



Sasidnu 
Supun 
Dasun 
Pathum 
Dilshan
Sampath
Kasun
Chaminda
Dananjaya
Malinga
Sanath
Mahela
Anjolo
Upun
Sugath
Josop
Kusal
Akila
Chatura
Malith
Amila
Thilak
Nuwan
Prabath
Nipuna
Kavidu
Raveen
Krishan
Eranda





dic = {
"aback":"පස්සට",
"aback":"පසුපසට",
"aback":"පුදුමයට",
"aback":"විස්මයට",
"abacus":"ඇබකසය",
"abacus	":"ගණක චතුරස්‍රය",
"abacus	":"ගණක රාමුව",
"abacus	":"බෝල රාමුව",
"abaft":"නැවක පසු භාගයෙහි",
"abaft":"පස්සෙන්",
"abaft":"අවරට",
"abandon":"අත්හරිනවා",
"abandon":"අතරමං කරනවා",
"abandon":"ප්‍රතික්ෂේප කරනවා",
"abandon":"පිටුපානවා",
"abandon":"වර්ජනය කරනවා"

}



sadasiri Niwasa 12/A
word Place 401 2/A
Amal Niwasa 1st Lane
27 Z/1 New Road
Wewa Rauma para 
Lake Road 4/5
Main Road
Cross Road
Temple Road
Pansala Para
School Road
Star Apatment
Sir Chitthampalam A Gardiner Mawatha